@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 ### BEGIN LICENSE
 # Copyright (c) 2012, Peter Levi <peterlevi@peterlevi.com>
@@ -29,6 +29,6 @@ class TestGoodreadsSource(unittest.TestCase):
         p = Jumble(["../data/plugins"])
         p.load()
         source = p.get_plugins(typename="GoodreadsSource")[0]
-        q = source["plugin"].get_for_author(u"Вежинов")
+        q = source["plugin"].get_for_author("Вежинов")
         self.assertTrue(len(q) > 0)
         self.assertEqual("Goodreads", q[0]["sourceName"])
