@@ -1,20 +1,18 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 ### BEGIN LICENSE
 # Copyright (c) 2012, Peter Levi <peterlevi@peterlevi.com>
-# This program is free software: you can redistribute it and/or modify it 
-# under the terms of the GNU General Public License version 3, as published 
+# This program is free software: you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 3, as published
 # by the Free Software Foundation.
-# 
-# This program is distributed in the hope that it will be useful, but 
-# WITHOUT ANY WARRANTY; without even the implied warranties of 
-# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
+#
+# This program is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranties of
+# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
 # PURPOSE.  See the GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License along 
+#
+# You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
 ### END LICENSE
-import io
-
 import os
 import hashlib
 from configobj import ConfigObj
@@ -23,7 +21,6 @@ from variety.Util import Util
 from variety_lib import varietyconfig
 
 import logging
-from variety import _str
 
 logger = logging.getLogger('variety')
 
@@ -46,9 +43,6 @@ class Options:
         REDDIT = 14
         BING = 15
         UNSPLASH = 16
-        RECOMMENDED = 19
-        LATEST = 20
-
         type_to_str = {
             FAVORITES: "favorites",
             FETCHED: "fetched",
@@ -63,21 +57,19 @@ class Options:
             REDDIT: "reddit",
             BING: "bing",
             UNSPLASH: "unsplash",
-            RECOMMENDED: "recommended",
-            LATEST: "latest",
         }
 
-        str_to_type = dict((v,k) for k, v in type_to_str.items())
+        str_to_type = {v: k for k, v in type_to_str.items()}
 
         dl_types = [DESKTOPPR, FLICKR, APOD, MEDIA_RSS, EARTH,
-                    WALLHAVEN, REDDIT, BING, UNSPLASH, RECOMMENDED, LATEST]
+                    WALLHAVEN, REDDIT, BING, UNSPLASH]
 
     class LightnessMode:
         DARK = 0
         LIGHT = 1
 
     def __init__(self):
-        self.configfile = os.path.expanduser(u"~/.config/variety/variety.conf")
+        self.configfile = os.path.expanduser("~/.config/variety/variety.conf")
 
     def read(self):
         self.set_defaults()
@@ -181,7 +173,7 @@ class Options:
                 pass
 
             try:
-                self.desired_color = map(int, config["desired_color"].split())
+                self.desired_color = list(map(int, config["desired_color"].split()))
                 for i, x in enumerate(self.desired_color):
                     self.desired_color[i] = max(0, min(255, x))
             except Exception:
@@ -255,16 +247,6 @@ class Options:
             except Exception:
                 pass
 
-            try:
-                self.facebook_show_dialog = config["facebook_show_dialog"].lower() in TRUTH_VALUES
-            except Exception:
-                pass
-
-            try:
-                self.facebook_message = config["facebook_message"].strip()
-            except Exception:
-                pass
-
             try:
                 self.copyto_enabled = config["copyto_enabled"].lower() in TRUTH_VALUES
             except Exception:
@@ -306,14 +288,14 @@ class Options:
                 pass
 
             try:
-                self.quotes_text_color = map(int, config["quotes_text_color"].split())
+                self.quotes_text_color = list(map(int, config["quotes_text_color"].split()))
                 for i, x in enumerate(self.quotes_text_color):
                     self.quotes_text_color[i] = max(0, min(255, x))
             except Exception:
                 pass
 
             try:
-                self.quotes_bg_color = map(int, config["quotes_bg_color"].split())
+                self.quotes_bg_color = list(map(int, config["quotes_bg_color"].split()))
                 for i, x in enumerate(self.quotes_bg_color):
                     self.quotes_bg_color[i] = max(0, min(255, x))
             except Exception:
@@ -331,7 +313,7 @@ class Options:
                 pass
 
             try:
-                self.quotes_text_color = map(int, config["quotes_text_color"].split())
+                self.quotes_text_color = list(map(int, config["quotes_text_color"].split()))
                 for i, x in enumerate(self.quotes_text_color):
                     self.quotes_text_color[i] = max(0, min(255, x))
             except Exception:
@@ -409,7 +391,7 @@ class Options:
 
             try:
                 custom_path = config["slideshow_custom_folder"]
-                if custom_path in ('None', 'Default') or not os.path.isdir():
+                if custom_path in ('None', 'Default') or not os.path.isdir(custom_path):
                     self.slideshow_custom_folder = Util.get_xdg_pictures_folder()
                 else:
                     self.slideshow_custom_folder = custom_path
@@ -466,14 +448,11 @@ class Options:
                     try:
                         self.sources.append(Options.parse_source(v))
                     except Exception:
-                        logger.exception(lambda: "Cannot parse source: " + v)
+                        logger.debug(lambda: "Cannot parse source: " + v, exc_info=True)
+                        logger.info('Ignoring no longer supported source %s', v)
 
             self.parse_autosources()
 
-            for s in self.sources:
-                if s[1] in (Options.SourceType.RECOMMENDED,) and not self.smart_enabled:
-                    s[0] = False
-
             if "filters" in config:
                 self.filters = []
                 filters = config["filters"]
@@ -496,7 +475,7 @@ class Options:
         changed = False
         for key, outdated_hashes in Options.OUTDATED_HASHES.items():
             if key in config:
-                current_hash = hashlib.md5(_str(config[key])).hexdigest()
+                current_hash = hashlib.md5(config[key].encode()).hexdigest()
                 if current_hash in outdated_hashes:
                     # entry is outdated: delete it and use the default
                     logger.warning(lambda: "Option " + key + " has an outdated value, using the new default")
@@ -506,7 +485,7 @@ class Options:
 
     def parse_autosources(self):
         try:
-            with io.open(varietyconfig.get_data_file("config", "sources.txt"), encoding='utf8') as f:
+            with open(varietyconfig.get_data_file("config", "sources.txt"), encoding='utf8') as f:
                 for line in f:
                     if not line.strip() or line.strip().startswith('#'):
                         continue
@@ -522,7 +501,7 @@ class Options:
 
     def parse_autofilters(self):
         try:
-            with io.open(varietyconfig.get_data_file("config", "filters.txt"), encoding='utf8') as f:
+            with open(varietyconfig.get_data_file("config", "filters.txt"), encoding='utf8') as f:
                 for line in f:
                     if not line.strip() or line.strip().startswith('#'):
                         continue
@@ -567,14 +546,14 @@ class Options:
 
         self.download_enabled = True
         self.download_interval = 600
-        self.download_folder = os.path.expanduser(u"~/.config/variety/Downloaded")
+        self.download_folder = os.path.expanduser("~/.config/variety/Downloaded")
         self.quota_enabled = True
         self.quota_size = 500
 
-        self.favorites_folder = os.path.expanduser(u"~/.config/variety/Favorites")
+        self.favorites_folder = os.path.expanduser("~/.config/variety/Favorites")
         self.favorites_operations = [["Downloaded", "Copy"], ["Fetched", "Move"], ["Others", "Copy"]]
 
-        self.fetched_folder = os.path.expanduser(u"~/.config/variety/Fetched")
+        self.fetched_folder = os.path.expanduser("~/.config/variety/Fetched")
         self.clipboard_enabled = False
         self.clipboard_use_whitelist = True
         self.clipboard_hosts = "alpha.wallhaven.cc,ns223506.ovh.net,wallpapers.net,flickr.com,imgur.com,deviantart.com,interfacelift.com,vladstudio.com".split(',')
@@ -595,12 +574,9 @@ class Options:
         self.smart_register_shown = False
         self.stats_notice_shown = False
 
-        self.smart_enabled = True
-        self.sync_enabled = True
-        self.stats_enabled = True
-
-        self.facebook_show_dialog = True
-        self.facebook_message = ""
+        self.smart_enabled = False
+        self.sync_enabled = False
+        self.stats_enabled = False
 
         self.copyto_enabled = False
         self.copyto_folder = "Default"
@@ -624,7 +600,7 @@ class Options:
         self.quotes_width = 70
         self.quotes_hpos = 100
         self.quotes_vpos = 40
-        self.quotes_favorites_file = os.path.expanduser(u"~/.config/variety/favorite_quotes.txt")
+        self.quotes_favorites_file = os.path.expanduser("~/.config/variety/favorite_quotes.txt")
 
         self.slideshow_sources_enabled = True
         self.slideshow_favorites_enabled = True
@@ -709,9 +685,6 @@ class Options:
             config["sync_enabled"] = str(self.sync_enabled)
             config["stats_enabled"] = str(self.stats_enabled)
 
-            config["facebook_show_dialog"] = str(self.facebook_show_dialog)
-            config["facebook_message"] = self.facebook_message
-
             config["copyto_enabled"] = str(self.copyto_enabled)
             config["copyto_folder"] = Util.collapseuser(self.copyto_folder)
 
@@ -788,6 +761,6 @@ if __name__ == "__main__":
 
     o = Options()
     o.read()
-    print o.sources
-    print o.filters
+    print(o.sources)
+    print(o.filters)
     o.write()
