@@ -1,6 +1,7 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 ### BEGIN LICENSE
-# Copyright (c) 2012, Peter Levi <peterlevi@peterlevi.com>
+# Copyright (c) 2012-2018, Peter Levi <peterlevi@peterlevi.com>
+# Copyright (c) 2017-2018, James Lu <james@overdrivenetworks.com>
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
 # by the Free Software Foundation.
@@ -21,31 +22,9 @@ gettext.textdomain('variety')
 import os
 import sys
 
-
-def _u(s):
-    if s is None:
-        return s
-    if isinstance(s, unicode):
-        return s
-    else:
-        return unicode(s, 'utf8')
-
-
-def _str(s):
-    if s is None:
-        return s
-    if isinstance(s, unicode):
-        return s.encode('utf8')
-    else:
-        return str(s)
-
-
 def _(text):
-    # Use "from locale import gettext" if we are deploying to /opt/extras
-    # Use "from gettext import gettext" when using standard Debian deployment
-    from gettext import gettext as _
-    return _u(_(text))
-
+    """Returns the translated form of text."""
+    return gettext.gettext(text)
 
 def safe_print(text, ascii_text=None):
     """
@@ -56,12 +35,13 @@ def safe_print(text, ascii_text=None):
     """
     try:
         print(text)
-    except: # UnicodeEncodeError can happen here if the terminal is strangely configured, but we are playing safe and catching everything
+    except:  # UnicodeEncodeError can happen here if the terminal is strangely configured, but we are playing safe and catching everything
         try:
-            logging.getLogger("variety").error('Error printing non-ascii text, terminal encoding is %s' % sys.stdout.encoding)
+            logging.getLogger("variety").error(
+                'Error printing non-ascii text, terminal encoding is %s' % sys.stdout.encoding)
             if ascii_text:
                 try:
-                    print ascii_text
+                    print(ascii_text)
                     return
                 except:
                     pass
@@ -73,15 +53,15 @@ def safe_print(text, ascii_text=None):
 class SafeLogger(logging.Logger):
     """
     Fixes UnicodeDecodeErrors errors in logging calls:
-    Accepts lambda instead of string messages. Catches errors when evaluatiating the passed lambda.
+    Accepts lambda as well string messages. Catches errors when evaluating the passed lambda.
     """
-    def makeRecord(self, name, level, fn, lno, msg, args, exc_info, func=None, extra=None):
+
+    def makeRecord(self, name, level, fn, lno, msg, *args, **kwargs):
         try:
-            new_msg = msg if isinstance(msg, basestring) else msg()
+            new_msg = msg if isinstance(msg, str) else msg()
         except:
             locale_info = 'Unknown'
             try:
-                import os
                 locale_info = 'Terminal encoding=%s, LANG=%s, LANGUAGE=%s' % (
                     sys.stdout.encoding, os.getenv('LANG'), os.getenv('LANGUAGE'))
                 logging.getLogger("variety").exception('Errors while logging. Locale info: %s' % locale_info)
@@ -90,7 +70,8 @@ class SafeLogger(logging.Logger):
                 pass
             new_msg = 'Errors while logging. Locale info: %s' % locale_info
 
-        return super(SafeLogger, self).makeRecord(name, level, fn, lno, new_msg, args, exc_info, func, extra)
+        return super().makeRecord(name, level, fn, lno, new_msg, *args, **kwargs)
+
 
 logging.setLoggerClass(SafeLogger)
 
@@ -104,14 +85,15 @@ import dbus, dbus.service, dbus.glib
 import logging
 
 import gi
+
 gi.require_version('Gtk', '3.0')
 
-from gi.repository import Gtk, Gdk, GObject # pylint: disable=E0611
+from gi.repository import Gtk, Gdk, GObject  # pylint: disable=E0611
 
 from variety import VarietyWindow
 from variety import ThumbsManager
 from variety import ThumbsWindow
-from variety.Util import Util
+from variety.Util import Util, ModuleProfiler
 from variety_lib.helpers import set_up_logging
 
 DBUS_KEY = 'com.peterlevi.Variety'
@@ -121,7 +103,7 @@ DBUS_PATH = '/com/peterlevi/Variety'
 class VarietyService(dbus.service.Object):
     def __init__(self, variety_window):
         self.variety_window = variety_window
-        bus_name = dbus.service.BusName(DBUS_KEY, bus = dbus.SessionBus())
+        bus_name = dbus.service.BusName(DBUS_KEY, bus=dbus.SessionBus())
         dbus.service.Object.__init__(self, bus_name, DBUS_PATH)
 
     @dbus.service.method(dbus_interface=DBUS_KEY, in_signature='as', out_signature='s')
@@ -129,14 +111,17 @@ class VarietyService(dbus.service.Object):
         result = self.variety_window.process_command(arguments, initial_run=False)
         return "" if result is None else result
 
+
 VARIETY_WINDOW = None
 
 terminate = False
 
+
 def sigint_handler(*args):
     global terminate
     terminate = True
 
+
 def check_quit():
     global terminate
     if not terminate:
@@ -153,46 +138,15 @@ def check_quit():
     Util.start_force_exit_thread(10)
 
 
-def monkeypatch_ssl():
-    """
-    HTTPS connections may fail on Ubuntu 12.04 to servers with disabled SSL with this error:
-    URLError: <urlopen error [Errno 1] _ssl.c:504: error:14077410:SSL routines:SSL23_GET_SERVER_HELLO:sslv3 alert handshake failure>.
-    This monkeypatching routine fixes the issue by forcing it to use TLSv1 instead of SSL.
-    Solution copied from http://askubuntu.com/questions/116020/python-https-requests-urllib2-to-some-sites-fail-on-ubuntu-12-04-without-proxy
-    """
-    import functools
-    import ssl
-
-    old_init = ssl.SSLSocket.__init__
-
-    @functools.wraps(old_init)
-    def ubuntu_openssl_bug_965371(self, *args, **kwargs):
-        kwargs['ssl_version'] = ssl.PROTOCOL_TLSv1
-        old_init(self, *args, **kwargs)
-
-    ssl.SSLSocket.__init__ = ubuntu_openssl_bug_965371
-
-
 def main():
     # Ctrl-C
     signal.signal(signal.SIGINT, sigint_handler)
     signal.signal(signal.SIGTERM, sigint_handler)
     signal.signal(signal.SIGQUIT, sigint_handler)
 
-    Util.makedirs(os.path.expanduser(u"~/.config/variety/"))
+    Util.makedirs(os.path.expanduser("~/.config/variety/"))
 
-    arguments = map(_u, sys.argv[1:])
-
-    # validate arguments and set up logging
-    options, args = VarietyWindow.VarietyWindow.parse_options(arguments)
-    set_up_logging(options.verbose)
-    monkeypatch_ssl()
-
-    if options.verbose >= 2:
-        Util.log_all(VarietyWindow.VarietyWindow)
-    if options.verbose >= 3:
-        Util.log_all(ThumbsManager.ThumbsManager)
-        Util.log_all(ThumbsWindow.ThumbsWindow)
+    arguments = sys.argv[1:]
 
     bus = dbus.SessionBus()
     # ensure singleton
@@ -207,6 +161,32 @@ def main():
             safe_print(result)
         return
 
+    # validate arguments and set up logging
+    # set_up_logging must be called after the DBus checks, only by one running instance,
+    # or the log file can be corrupted
+    options, args = VarietyWindow.VarietyWindow.parse_options(arguments)
+    set_up_logging(options.verbose)
+
+    if options.verbose >= 2:
+        profiler = ModuleProfiler()
+        if options.verbose >= 4:
+            # The main variety package
+            pkgname = os.path.dirname(__file__)
+            profiler.log_path(pkgname)
+
+            if options.verbose >= 5:
+                # Track variety_lib
+                profiler.log_path(pkgname + "_lib")
+        else:
+            # Cherry-picked log items carried over from variety 0.6.x
+            profiler.log_class(VarietyWindow.VarietyWindow)
+
+            if options.verbose >= 3:
+                profiler.log_class(ThumbsManager.ThumbsManager)
+                profiler.log_class(ThumbsWindow.ThumbsWindow)
+
+        profiler.start()
+
     # Run the application.
     window = VarietyWindow.VarietyWindow()
     global VARIETY_WINDOW
